@@ -78,15 +78,8 @@ void libvk_set_settings(gchar *params)
 {
     g_debug("%s:%d: Call nd_set_settings()", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
-    "<TransitData>\
-<SourceID>", driver_module->id, "</SourceID>\
-<TargetID>", DRIVER_ID, "</TargetID>\
-<Content>\
-<Request class=\"settings\" function = \"setSettings\">",
-    params,
-"</Request>\
-</Content>\
-</TransitData>", NULL);
+    "<Request class=\"", CLASS_SETTINGS, "\" function = \"", SET_SETTINGS, "\">",
+    params, "</Request>", NULL);
     xmlDocPtr req = xmlParseDoc(req_string);
 
     xmlDocPtr resp = NULL;
@@ -107,15 +100,9 @@ gboolean libvk_get_settings(SharingAccount* account)
 
     msa_print("%s:%d: Call nd_get_settings()", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
-    "<TransitData>\
-<SourceID>", driver_module->id, "</SourceID>\
-<TargetID>", DRIVER_ID, "</TargetID>\
-<Content>\
-<Request class=\"settings\" function = \"getSettings\">\
+    "<Request class=\"", CLASS_SETTINGS, "\" function = \"", GET_SETTINGS, "\">\
 <Params/>\
-</Request>\
-</Content>\
-</TransitData>", NULL);
+</Request>", NULL);
     xmlDocPtr req = xmlParseDoc(req_string);
     xmlDocPtr resp = NULL;
 
@@ -153,15 +140,9 @@ gboolean libvk_testConnection()
 
     msa_print("%s:%d: Call testConnection()\n", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
-    "<TransitData>\
-    <SourceID>", driver_module->id, "</SourceID>\
-    <TargetID>", DRIVER_ID, "</TargetID>\
-    <Content>\
-    <Request class=\"settings\" function = \"testConnection\">\
+    "<Request class=\"", CLASS_SETTINGS, "\" function = \"", TEST_CONNECTION, "\">\
     <Params/>\
-    </Request>\
-    </Content>\
-    </TransitData>", NULL);
+    </Request>", NULL);
     xmlDocPtr req = xmlParseDoc(req_string);
     xmlDocPtr resp = NULL;
 
@@ -192,16 +173,10 @@ SharingPluginInterfaceSendResult
 {
     g_debug("%s:%d: Call nd_getAlbums()", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
-    "<TransitData id=\"1\" type=\"data\">\
-<SourceID>", driver_module->id, "</SourceID>\
-<TargetID>", DRIVER_ID, "</TargetID>\
-<Content>\
-<Request class=\"photos\" function=\"getAlbums\">\
+    "<Request class=\"", CLASS_PHOTOS, "\" function=\"", GET_LIST_ALBUMS, "\">\
 <Params>\
 </Params>\
-</Request>\
-</Content>\
-</TransitData>", NULL);
+</Request>", NULL);
     xmlDocPtr req = xmlParseDoc(req_string);
     xmlDocPtr resp = NULL;
 
@@ -238,10 +213,11 @@ SharingPluginInterfaceSendResult
 
         if (root_node != NULL) {
             code = (gchar*)xmlNodeGetContent(root_node);
-            if(g_strcmp0(code, "407") == 0) {
+            if(g_strcmp0(code, DRV_AUTH_ERROR_CODE) == 0 ||
+               g_strcmp0(code, DRV_AUTH_CANCEL_CODE) == 0) {
                 ret_val = SHARING_SEND_ERROR_AUTH;
             }
-            if(g_strcmp0(code, "404") == 0) {
+            if(g_strcmp0(code, DRV_NETW_ERROR_CODE) == 0) {
                 ret_val =  SHARING_SEND_ERROR_CONNECTION;
             }
         }
@@ -267,19 +243,13 @@ gboolean libvk_uploadPhoto(gchar *aid, gchar *file, gchar *file_name)
 
     g_debug("%s:%d: Call nd_uploadPhoto()", __FILE__, __LINE__);
     xmlChar *req_string = (xmlChar*)g_strconcat("<?xml version=\"1.0\"?>",
-    "<TransitData id=\"1\" type=\"data\">\
-<SourceID>", driver_module->id, "</SourceID>\
-<TargetID>", DRIVER_ID, "</TargetID>\
-<Content>\
-<Request class=\"photos\" function=\"uploadPhoto\">\
+    "<Request class=\"", CLASS_PHOTOS, "\" function=\"", UPLOAD_PHOTO, "\">\
 <Params>\
 <string name=\"albumId\">", aid, "</string>\
 <string name=\"file\">", file, "</string>\
 <string name=\"fileName\">", file_name, "</string>\
 </Params>\
-</Request>\
-</Content>\
-</TransitData>", NULL);
+</Request>", NULL);
     xmlDocPtr req = xmlParseDoc(req_string);
     xmlDocPtr resp = NULL;
 
