@@ -11,12 +11,9 @@
 
 #include <stdio.h>
 #include <glib.h>
-//#include <sharing-account.h>
-//#include <sharing-http.h>
 #include <osso-log.h>
 #include <conicconnection.h>
 #include "validate.h"
-//#include "common.h"
 #include "libvkontakte_interface.h"
 
 /**
@@ -35,14 +32,9 @@ SharingPluginInterfaceAccountValidateResult validate (SharingAccount* account,
     SharingPluginInterfaceAccountValidateResult ret =
         SHARING_ACCOUNT_VALIDATE_SUCCESS;
     
-    const gchar* proxy_host = con_ic_connection_get_proxy_host(con,
-                        CON_IC_PROXY_PROTOCOL_HTTP);
-    gint proxy_port = con_ic_connection_get_proxy_port(con,
-                        CON_IC_PROXY_PROTOCOL_HTTP);
-
     gchar* account_name = sharing_account_get_username (account);
 
-    if(!libvk_init((gchar*)proxy_host, proxy_port, account_name)){
+    if(!libvk_init(con, account_name)){
         ret = SHARING_ACCOUNT_VALIDATE_ERROR_UNKNOWN;
     } else {
         if(libvk_testConnection()){
